@@ -2,7 +2,7 @@ from fastapi import APIRouter, Request
 from fastapi.encoders import jsonable_encoder
 from fastapi.responses import JSONResponse
 
-router = APIRouter(prefix="/api/v1/echo", tags=["auth"])
+router = APIRouter(prefix="/api/v1/echo", tags=["echo"])
 
 
 @router.get("")
